---
nav: Why Vuetify?
meta:
  title: Why you should be using Vuetify
  description: Vuetify has an extremely active community, provides easy to use Material Design components and is consistently updated.
  keywords: why vuetify, why choose vuetify, best vue framework, best ui framework
related:
  - /getting-started/installation
  - /introduction/roadmap
  - /about/meet-the-team
---

# Introduction

Learn more about what Vuetify is, how to create an application from scratch, browse API references, sample code, tutorials, and more.

<!-- <promoted slug="vuemastery-getting-started" /> -->

## Getting started

The easiest way to try Vuetify is to use our [Codepen template](https://template.vuetifyjs.com/). This template is used by all examples within the documentation and is the perfect sandbox to play around with the framework. If you prefer to use a local `index.html` file, we have a guide on how to [use via CDN](/getting-started/installation/#usage-with-cdn).

For additional installation options such as **Nuxt** and **VuePress**, visit the [Installation](/getting-started/installation/) page.

## What is Vuetify?

Vuetify is a complete UI framework built on top of Vue.js. The goal of the project is to provide developers with the tools they need to build rich and engaging user experiences. Unlike other frameworks, Vuetify is designed from the ground up to be easy to learn and rewarding to master with hundreds of carefully crafted components from the [Material Design specification](https://material.io/).

Vuetify takes a mobile first approach to design which means your application just works out of the box—whether it's on a phone, tablet, or desktop computer.

If you are an experienced developer and want to compare Vuetify to other libraries/frameworks, check out our [Vue Framework Comparison Chart](#comparison).

## Why Vuetify?

Since its initial release in 2014, [Vue.js](https://vuejs.org/) has grown to be one of the most popular JavaScript frameworks in the world. One of the reasons for this popularity is the wide use of _components_ which enable developers to create concise modules to be used and re-used throughout their application. UI Libraries are collections of these modules that implement a specific style guideline and provide the necessary tools to build expansive web applications.

Vuetify is developed exactly according to [Material Design specification](https://material.io/) with every component meticulously crafted to be modular, responsive, and performant. Customize your application with unique and dynamic [Layouts](/features/layouts/) and customize the styles of your components using [SASS variables](/features/sass-variables/).

Vuetify has a very active development cycle and is patched weekly, responding to community issues and reports at breakneck speed, allowing you to get your hands on bug fixes and enhancements more often. In addition, every major release is accompanied with 18 months of [Long-term support](/introduction/long-term-support/) for the previous minor version.

When you develop with Vuetify, you are never alone. Stuck on a problem? Take advantage of our massive [Discord community](https://community.vuetifyjs.com/) and collaborate with other Vuetify developers in one of our public help channels. Need a more personalized support solution? Vuetify offers **elite support** through [GitHub sponsorship](https://github.com/sponsors/johnleider) with options tailored to individuals and businesses. Check out some other ways to [Sponsor Vuetify development](/about/sponsors-and-backers/).

Below is a list of the top Vue.js frameworks and the features that we feel are important to developers and businesses when choosing a UI library.

<page-component path="introduction/Comparison" />

So what are you waiting for? Head over to the [Installation](/getting-started/installation/) page and start building your next great idea today.

## Feature Guides

Learn more about the inner workings of Vuetify and become a skilled **v-developer** with our detailed feature guides. Each guide is designed to teach you how to get the most out of your development experience with information on: how to build responsive pages using [Layouts](/features/layouts/), how to customize the style of your application with [SASS variables](/features/sass-variables/), and how to slim down your application's package size via [Treeshaking](/features/treeshaking/), and more.

| Feature | Skill level | Time to read |
| ------- | ----------- | ------------ |
| [Bidirectionality (LTR/RTL)](/features/bidirectionality/) | Beginner | 1 min |
| [Global configuration](/features/global-config/) | Beginner | 1 min |
| [Icons](/features/icon-fonts/) | Beginner | 15 min |
| [Layouts](/features/layouts/) | Beginner | 5 min |
| [Theme](/features/theme/) | Beginner | 15 min |
| [Accessibility (a11y)](/features/accessibility) | Intermediate | 10 min |
| [Breakpoints](/features/breakpoints) | Intermediate | 15 min |
| [Internationalization (i18n)](/features/internationalization/) | Intermediate | 5 min |
| [Programmatic scrolling](/features/scrolling/) | Intermediate | 2 min |
| [SASS variables](/features/sass-variables/) | Intermediate | 10 min |
| [Presets](/features/presets/) | Advanced | 15 min |
| [Treeshaking](/features/treeshaking/) | Advanced | 15 min |

Can't find what you're looking for? Help us improve! Please reach out to [john@vuetifyjs.com](mailto:john@vuetifyjs.com) with your feedback or join us in the Vuetify [Discord community](https://community.vuetifyjs.com/).

<!-- <promoted slug="vuetify-discord" /> -->

<backmatter />
